@@ -10,7 +10,6 @@ from featuretools.primitives.base import (
     PrimitiveBase,
     TransformPrimitive,
 )
-from featuretools.primitives.utils import serialize_primitive
 from featuretools.utils.wrangle import _check_time_against_column, _check_timedelta
 
 _ES_REF = {}
@@ -70,13 +69,12 @@ class FeatureBase(object):
         return FeatureOutputSlice(self, key)
 
     @classmethod
-    def from_dictionary(
-        cls, arguments, entityset, dependencies, primitives_deserializer
-    ):
+    def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         raise NotImplementedError("Must define from_dictionary on FeatureBase subclass")
 
     def rename(self, name):
-        """Rename Feature, returns copy"""
+        """Rename Feature, returns copy. Will reset any custom feature column names
+        to their default value."""
         feature_copy = self.copy()
         feature_copy._name = name
         feature_copy._names = None
@@ -103,6 +101,33 @@ class FeatureBase(object):
                     ]
         return self._names
 
+    def set_feature_names(self, names):
+        """Set new values for the feature column names, overriding the default values.
+        Number of names provided much match the number of output columns defined for
+        the feature. Only works for features that have more than one output column. Use
+        ``Feature.rename`` to change the column name for single output features.
+
+        Args:
+            names (list[str]): List of names to use for the output feature columns. Provided
+                names must be unique.
+        """
+        if self.number_output_features == 1:
+            raise ValueError(
+                "The set_feature_names can only be used on features that have more than one output column."
+            )
+
+        num_new_names = len(names)
+        if self.number_output_features != num_new_names:
+            raise ValueError(
+                "Number of names provided must match the number of output features:"
+                f" {num_new_names} name(s) provided, {self.number_output_features} expected."
+            )
+
+        if len(set(names)) != num_new_names:
+            raise ValueError("Provided output feature names must be unique.")
+
+        self._names = names
+
     def get_function(self, **kwargs):
         return self.primitive.get_function(**kwargs)
 
@@ -423,9 +448,7 @@ class IdentityFeature(FeatureBase):
         )
 
     @classmethod
-    def from_dictionary(
-        cls, arguments, entityset, dependencies, primitives_deserializer
-    ):
+    def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         dataframe_name = arguments["dataframe_name"]
         column_name = arguments["column_name"]
         column = entityset[dataframe_name].ww[column_name]
@@ -443,7 +466,7 @@ class IdentityFeature(FeatureBase):
 
     def get_arguments(self):
         return {
-            "name": self._name,
+            "name": self.get_name(),
             "column_name": self.column_name,
             "dataframe_name": self.dataframe_name,
         }
@@ -516,9 +539,7 @@ class DirectFeature(FeatureBase):
         return relationship
 
     @classmethod
-    def from_dictionary(
-        cls, arguments, entityset, dependencies, primitives_deserializer
-    ):
+    def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         base_feature = dependencies[arguments["base_feature"]]
         relationship = Relationship.from_dictionary(
             arguments["relationship"], entityset
@@ -562,7 +583,7 @@ class DirectFeature(FeatureBase):
     def get_arguments(self):
         _is_forward, relationship = self.relationship_path[0]
         return {
-            "name": self._name,
+            "name": self.get_name(),
             "base_feature": self.base_features[0].unique_name(),
             "relationship": relationship.to_dictionary(),
         }
@@ -683,9 +704,7 @@ class AggregationFeature(FeatureBase):
         return relationship_path, path_is_unique
 
     @classmethod
-    def from_dictionary(
-        cls, arguments, entityset, dependencies, primitives_deserializer
-    ):
+    def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         base_features = [dependencies[name] for name in arguments["base_features"]]
         relationship_path = [
             Relationship.from_dictionary(r, entityset)
@@ -694,10 +713,6 @@ class AggregationFeature(FeatureBase):
         parent_dataframe_name = relationship_path[0].parent_dataframe.ww.name
         relationship_path = RelationshipPath([(False, r) for r in relationship_path])
 
-        primitive = primitives_deserializer.deserialize_primitive(
-            arguments["primitive"]
-        )
-
         use_previous_data = arguments["use_previous"]
         use_previous = use_previous_data and Timedelta.from_dictionary(
             use_previous_data
@@ -706,7 +721,7 @@ class AggregationFeature(FeatureBase):
         where_name = arguments["where"]
         where = where_name and dependencies[where_name]
 
-        return cls(
+        feat = cls(
             base_features=base_features,
             parent_dataframe_name=parent_dataframe_name,
             primitive=primitive,
@@ -715,6 +730,8 @@ class AggregationFeature(FeatureBase):
             where=where,
             name=arguments["name"],
         )
+        feat._names = arguments.get("feature_names")
+        return feat
 
     def copy(self):
         return AggregationFeature(
@@ -759,14 +776,17 @@ class AggregationFeature(FeatureBase):
         )
 
     def get_arguments(self):
-        return {
-            "name": self._name,
+        arg_dict = {
+            "name": self.get_name(),
             "base_features": [feat.unique_name() for feat in self.base_features],
             "relationship_path": [r.to_dictionary() for _, r in self.relationship_path],
-            "primitive": serialize_primitive(self.primitive),
+            "primitive": self.primitive,
             "where": self.where and self.where.unique_name(),
             "use_previous": self.use_previous and self.use_previous.get_arguments(),
         }
+        if self.number_output_features > 1:
+            arg_dict["feature_names"] = self.get_feature_names()
+        return arg_dict
 
     def relationship_path_name(self):
         if self._path_is_unique:
@@ -792,16 +812,13 @@ class TransformFeature(FeatureBase):
         )
 
     @classmethod
-    def from_dictionary(
-        cls, arguments, entityset, dependencies, primitives_deserializer
-    ):
+    def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         base_features = [dependencies[name] for name in arguments["base_features"]]
-        primitive = primitives_deserializer.deserialize_primitive(
-            arguments["primitive"]
-        )
-        return cls(
+        feat = cls(
             base_features=base_features, primitive=primitive, name=arguments["name"]
         )
+        feat._names = arguments.get("feature_names")
+        return feat
 
     def copy(self):
         return TransformFeature(self.base_features, self.primitive)
@@ -817,11 +834,14 @@ class TransformFeature(FeatureBase):
         )
 
     def get_arguments(self):
-        return {
-            "name": self._name,
+        arg_dict = {
+            "name": self.get_name(),
             "base_features": [feat.unique_name() for feat in self.base_features],
-            "primitive": serialize_primitive(self.primitive),
+            "primitive": self.primitive,
         }
+        if self.number_output_features > 1:
+            arg_dict["feature_names"] = self.get_feature_names()
+        return arg_dict
 
 
 class GroupByTransformFeature(TransformFeature):
@@ -841,20 +861,17 @@ class GroupByTransformFeature(TransformFeature):
         )
 
     @classmethod
-    def from_dictionary(
-        cls, arguments, entityset, dependencies, primitives_deserializer
-    ):
+    def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         base_features = [dependencies[name] for name in arguments["base_features"]]
-        primitive = primitives_deserializer.deserialize_primitive(
-            arguments["primitive"]
-        )
         groupby = dependencies[arguments["groupby"]]
-        return cls(
+        feat = cls(
             base_features=base_features,
             primitive=primitive,
             groupby=groupby,
             name=arguments["name"],
         )
+        feat._names = arguments.get("feature_names")
+        return feat
 
     def copy(self):
         # the groupby feature is appended to base_features in the __init__
@@ -883,12 +900,15 @@ class GroupByTransformFeature(TransformFeature):
             for feat in self.base_features
             if feat.unique_name() != self.groupby.unique_name()
         ]
-        return {
-            "name": self._name,
+        arg_dict = {
+            "name": self.get_name(),
             "base_features": feature_names,
-            "primitive": serialize_primitive(self.primitive),
+            "primitive": self.primitive,
             "groupby": self.groupby.unique_name(),
         }
+        if self.number_output_features > 1:
+            arg_dict["feature_names"] = self.get_feature_names()
+        return arg_dict
 
 
 class Feature(object):
@@ -975,15 +995,13 @@ class FeatureOutputSlice(FeatureBase):
 
     def get_arguments(self):
         return {
-            "name": self._name,
+            "name": self.get_name(),
             "base_feature": self.base_feature.unique_name(),
             "n": self.n,
         }
 
     @classmethod
-    def from_dictionary(
-        cls, arguments, entityset, dependencies, primitives_deserializer
-    ):
+    def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         base_feature_name = arguments["base_feature"]
         base_feature = dependencies[base_feature_name]
         n = arguments["n"]
