@@ -46,14 +46,21 @@ def load_features(features, profile_name=None):
 
         .. code-block:: python
 
+            # Option 1
             filepath = os.path.join('/Home/features/', 'list.json')
-            ft.load_features(filepath)
+            features = ft.load_features(filepath)
 
-            f = open(filepath, 'r')
-            ft.load_features(f)
+            # Option 2
+            filepath = os.path.join('/Home/features/', 'list.json')
+            with open(filepath, 'r') as f:
+                features = ft.load_features(f)
+
+            # Option 3
+            filepath = os.path.join('/Home/features/', 'list.json')
+            with open(filepath, 'r') as :
+                feature_str = f.read()
+            features = ft.load_features(feature_str)
 
-            feature_str = f.read()
-            ft.load_features(feature_str)
 
     .. seealso::
         :func:`.save_features`
@@ -78,7 +85,12 @@ class FeaturesDeserializer(object):
         self._check_schema_version()
         self.entityset = deserialize_es(features_dict["entityset"])
         self._deserialized_features = {}  # name -> feature
-        self._primitives_deserializer = PrimitivesDeserializer()
+        primitive_deserializer = PrimitivesDeserializer()
+        primitive_definitions = features_dict["primitive_definitions"]
+        self._deserialized_primitives = {
+            k: primitive_deserializer.deserialize_primitive(v)
+            for k, v in primitive_definitions.items()
+        }
 
     @classmethod
     def load(cls, features, profile_name):
@@ -109,6 +121,10 @@ class FeaturesDeserializer(object):
 
         feature_dict = self.features_dict["feature_definitions"][feature_name]
         dependencies_list = feature_dict["dependencies"]
+        primitive = None
+        primitive_id = feature_dict["arguments"].get("primitive")
+        if primitive_id is not None:
+            primitive = self._deserialized_primitives[primitive_id]
 
         # Collect dependencies into a dictionary of name -> feature.
         dependencies = {
@@ -122,9 +138,7 @@ class FeaturesDeserializer(object):
             raise RuntimeError('Unrecognized feature type "%s"' % type)
 
         args = feature_dict["arguments"]
-        feature = cls.from_dictionary(
-            args, self.entityset, dependencies, self._primitives_deserializer
-        )
+        feature = cls.from_dictionary(args, self.entityset, dependencies, primitive)
 
         self._deserialized_features[feature_name] = feature
         return feature
