@@ -3,7 +3,7 @@ from .cli_utils import (
     get_featuretools_root,
     get_installed_packages,
     get_sys_info,
-    show_info
+    show_info,
 )
 from .entry_point import entry_point
 from .gen_utils import make_tqdm_iterator
