@@ -53,7 +53,9 @@ def check_schema_version(cls, cls_type):
             version_string = cls.features_dict["schema_version"]
 
         current = SCHEMA_VERSION.split(".")
+        current = [int(val) for val in current]
         saved = version_string.split(".")
+        saved = [int(val) for val in saved]
 
         warning_text_upgrade = (
             "The schema version of the saved %s"
